#<profile4xi profile = "12" />
# -------------------------------------------------------------------------------------------------
#<program4xi program = "constant_family4xi.py">
#<abstract4xi abstract = "Provides the class ConstantFamily4Xi."/>
#<refer4xi reference = "connection.py"/>
#<state4xi status = "ACK4tagging; ACK4moduletesting; NACK4systemtesting; [Rel 7.21]"/>
# -------------------------------------------------------------------------------------------------
#


# -------------------------------------------------------------------------------------------------
# Public API
# -------------------------------------------------------------------------------------------------
#<interface4xi interface = " 
__all__ = [ 'constant_family4xi', 'ConstantFamily4Xi', 
            'init_af_inet4xi', 'init_af_unix4xi', 'init_af_pipe4xi',
            'set_af_inet4xi', 'set_af_unix4xi', 'set_af_pipe4xi',
            'get_af_inet4xi', 'get_af_unix4xi', 'get_af_pipe4xi',
            'init_default_family4xi', 'init_families4xi', 'set_default_family4xi',
            'set_families4xi', 'get_default_family4xi', 'get_families4xi']
#"
#/>

# -------------------------------------------------------------------------------------------------
# Standard Imports                          
# -------------------------------------------------------------------------------------------------
#<standardize4xi standard = "
import errno
import io
import itertools
import os
import pickle
import select
import socket
import struct
import sys
import time
import tempfile
try:
    import _winapi
    from _winapi import WAIT_OBJECT_0, WAIT_TIMEOUT, INFINITE
except ImportError:
    if sys.platform == 'win32':
        raise
    _winapi = None        
#"
#/>

# -------------------------------------------------------------------------------------------------
# Multiprocessing Imports                          
# -------------------------------------------------------------------------------------------------
#<process4xi process = "
import _multiprocessing
from multiprocessing import connection
#"
#/>
     
# -------------------------------------------------------------------------------------------------
# DragonXi imports                              
# -------------------------------------------------------------------------------------------------
#<dragonize4xi dragonization = "
from ace_object4xi import ace_object4xi
from constant_system4xi import ConstantSystem4Xi
from constant_system4xi import get_windows_system4xi
from print4xi import print4xi
from reason_object4xi import reason_object4xi
from sense_object4xi import sense_object4xi
from time4xi import time4xi
#"
#/>

# -------------------------------------------------------------------------------------------------
# Global object                              
# -------------------------------------------------------------------------------------------------
#<globalize4xi globalization = "
global AF_INET4XI
global AF_UNIX4XI
global AF_PIPE4XI
global default_family4xi
global families4xi
#"
#/>

# -------------------------------------------------------------------------------------------------
# Settings
# -------------------------------------------------------------------------------------------------
#<set4xi setting = "
AF_INET4XI = 'AF_INET'
AF_UNIX4XI = 'AF_UNIX'
AF_PIPE4XI = 'AF_PIPE'

default_family4xi = 'AF_PIPE'
families4xi = ['AF_PIPE']


if hasattr(socket, 'AF_UNIX'):
    default_family4xi = 'AF_UNIX'
    families4xi += ['AF_UNIX']

if sys.platform == get_windows_system4xi(): 
    default_family4xi = 'AF_PIPE'
    families4xi += ['AF_PIPE']
#"
#"/>



# -------------------------------------------------------------------------------------------------
#<function4xi function = "constant-family4xi" usage = "
# defines constants for connections
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------
def constant_family4xi(param_constant_family4xi):
    '''
    constant_family4xi defines constants for connections

    '''
    global AF_INET4XI
    global AF_UNIX4XI
    global AF_PIPE4XI
    global default_family4xi
    global families4xi  

    class2print  =  'constant_family4xi' 
    method2print = 'constant_family4xi'  

    message2print = "{started" + "; constant-family4xi-started: " + str(constant_family4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)            
         
    message2print = "{passed" + "; param-constant-family4xi-passed-to-constant-family4xi: " + str(param_constant_family4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
              
    if param_constant_family4xi == 1:
    
        message2print = "{returning" + "; af-inet4xi-returning-by-constant-family4xi: " + str(AF_INET4XI) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
             
        return AF_INET4XI

    if param_constant_family4xi == 2:
    
        message2print = "{returning" + "; af-unix4xi-returning-by-constant-family4xi: " + str(AF_UNIX4XI) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
        return AF_UNIX4XI        

    if param_constant_family4xi == 3:
    
        message2print = "{returning" + "; af-pipe4xi-returning-by-constant-family4xi: " + str(AF_PIPE4XI) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
        return AF_PIPE4XI

    if param_constant_family4xi == 4:
    
        message2print = "{returning" + "; default-family4xi-returning-by-constant-family4xi: " + str(default_family4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
        return default_family4xi        
        
    if param_constant_family4xi == 5:
    
        message2print = "{returning" + "; families4xi-returning-by-constant-family4xi: " + str(families4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
        
        return families4xi

    message2print = "{returning" + "; false-returning-by-constant-family4xi: " + str(False) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)           
    
    return False        
#</function4xi> 

 

# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-af-inet4xi" usage = "
# initializes family constant AF_INET4XI
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_af_inet4xi(inet_param):          
    '''
    init_af_inet4xi initializes family constant AF_INET4XI
    '''
    global AF_INET4XI


    class2print = 'init_af_inet4xi'
    method2print =  'init_af_inet4xi' 
    

    message2print = "{started" + "; init-af-inet4xi-started: " + str(init_af_inet4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  

         
    message2print = "{passed" + "; inet-param-passed-to-init-af-inet4xi: " + str(inet_param) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
  
             
    if inet_param:
        AF_INET4XI = inet_param
    else:
        AF_INET4XI = 'AF_INET'    
    
    message2print = "{initialized" + "; af-inet4xi-initialized-by-init-af-inet4xi to: " + str(AF_INET4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)
    
    message2print = "{returning" + "; init-af-inet4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                     
#</function4xi> 

                  
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-af-unix4xi" usage = "
# initializes family constant AF_UNIX4XI
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_af_unix4xi(unix_param):          
    '''
    init_af_unix4xi initializes family constant AF_UNIX4XI
    '''
    global AF_UNIX4XI


    class2print = 'init_af_unix4xi'
    method2print = 'init_af_unix4xi'
    

    message2print = "{started" + "; init-af-unix4xi-started: " + str(init_af_unix4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
         
    message2print = "{passed" + "; unix-param-passed-to-init-af-unix4xi: " + str(unix_param) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
  
           
    if unix_param:
        AF_UNIX4XI = unix_param
    else:
        AF_UNIX4XI = 'AF_UNIX'
        
    message2print = "{initialized" + "; af-unix4xi-initialized-by-init-af-unix4xi to: " + str(AF_UNIX4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)
    
    message2print = "{returning" + "; init-af-unix4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
         

#</function4xi> 

                  
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-af-pipe4xi" usage = "
# initializes family constant AF_PIPE4XI
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_af_pipe4xi(pipe_param):          
    '''
    init_af_pipe4xi initializes family constant AF_PIPE4XI
    '''
    global AF_PIPE4XI


    class2print = 'init_af_pipe4xi'
    method2print = 'init_af_pipe4xi'
    

    message2print = "{started" + "; init-af-pipe4xi-started: " + str(init_af_pipe4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
    
         
    message2print = "{passed" + "; pipe-param-passed-to-init-af-pipe4xi: " + str(pipe_param) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
            
    if pipe_param:
        AF_PIPE4XI = pipe_param    
    else:
        AF_PIPE4XI = 'AF_PIPE'     
        
    message2print = "{initialized" + "; af-pipe4xi-initialized-by-init-af-pipe4xi to: " + str(AF_PIPE4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)
    
    message2print = "{returning" + "; init-af-pipe4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
        

#</function4xi> 

              
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-default-family4xi" usage = "
# initializes family constant default_family4xi
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_default_family4xi(param_default_family4xi=None):          
    '''
    init_default_family4xi initializes family constant default_family4xi
    '''
    global default_family4xi


    
    class2print = 'init_default_family4xi'
    method2print = 'init_default_family4xi'
    

    message2print = "{started" + "; init-default-family4xi-started: " + str(init_default_family4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
         
    message2print = "{passed" + "; param-default-family4xi-passed-to-init-default-family4xi: " + str(param_default_family4xi) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
  
           
    default_family4xi = 'AF_INET'

    if hasattr(socket, 'AF_UNIX'):
        default_family4xi = 'AF_UNIX'
    

    if sys.platform == 'win32':
        default_family4xi = 'AF_PIPE'
        
        
    message2print = "{initialized" + "; default-family4xi-initialized-by-init-default-family4xi to: " + str(default_family4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)
    
    message2print = "{returning" + "; init-default-family4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
        

#</function4xi> 

                         
                           
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-families4xi" usage = "
# initializes family constant families4xi
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_families4xi(families_param=None):          
    '''
    init_families4xi initializes family constant families4xi
    ''' 
    global families4xi
    
    class2print = 'init_families4xi'
    method2print = 'init_families4xi'

    message2print = "{started" + "; init-families4xi-started: " + str(init_families4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
           
         
    message2print = "{passed" + "; families-param-passed-to-init-families4xi: " + str(families_param) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
           
    if families_param:
        families4xi = families_param

    else:
        families4xi = ['AF_INET']

        if hasattr(socket, 'AF_UNIX'):
            families4xi += ['AF_UNIX']
           
        if sys.platform == get_windows_system4xi(): #WINDOWS324XI dragonized
            families4xi += ['AF_PIPE'] 
      
        
    message2print = "{initialized" + "; families4xi-initialized-by-init-families4xi to: " + str(families4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)
  
    
    message2print = "{returning" + "; init-families4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                      
#</function4xi> 

 

                
                    
# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-af-inet4xi" usage = "
# sets family constant AF_INET4XI
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_af_inet4xi(inet_param):          
    '''
    set_af_inet4xi sets family constant AF_INET4XI
    '''
    global AF_INET4XI

             
    class2print = 'set_af_inet4xi'
    method2print = 'set_af_inet4xi'
    

    message2print = "{started" + "; set-af-inet4xi-started: " + str(set_af_inet4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  

         
    message2print = "{passed" + "; inet-param-passed-to-set-af-inet4xi: " + str(inet_param) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
             
    if inet_param:
        AF_INET4XI = inet_param
    else:
        AF_INET4XI = 'AF_INET'
     
    message2print = "{set" + "; af-inet4xi-set-by-set-af-inet4xi to: " + str(AF_INET4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)          
    
    message2print = "{returning" + "; set-af-inet4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
              

#</function4xi> 

                 
# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-af-unix4xi" usage = "
# sets family constant AF_UNIX4XI
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_af_unix4xi(unix_param):          
    '''
    set_af_unix4xi sets family constant AF_UNIX4XI
    '''
    global AF_UNIX4XI

            
    class2print = 'set_af_unix4xi'
    method2print = 'set_af_unix4xi'
    

    message2print = "{started" + "; set-af-unix4xi-started: " + str(set_af_unix4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
         
    message2print = "{passed" + "; unix-param-passed-to-set-af-unix4xi: " + str(unix_param) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
  
         
    if unix_param:
        AF_UNIX4XI = unix_param
    else:
        AF_UNIX4XI = 'AF_UNIX'
    
     
    message2print = "{set" + "; af-unix4xi-set-by-set-af-unix4xi to: " + str(AF_UNIX4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)          
        
    
    message2print = "{returning" + "; set-af-unix4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
  
#</function4xi> 

                  
# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-af-pipe4xi" usage = "
# sets family constant AF_PIPE4XI
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_af_pipe4xi(pipe_param):          
    '''
    set_af_pipe4xi sets family constant AF_PIPE4XI
    '''
    global AF_PIPE4XI

           
    class2print = 'set_af_pipe4xi'
    method2print = 'set_af_pipe4xi'
    

    message2print = "{started" + "; set-af-pipe4xi-started: " + str(set_af_pipe4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
         
    message2print = "{passed" + "; pipe-param-passed-to-set-af-pipe4xi: " + str(pipe_param) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
  
            
    AF_PIPE4XI = pipe_param    
     
    message2print = "{set" + "; af-pipe4xi-set-by-set-af-pipe4xi to: " + str(AF_PIPE4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)          
        
    
    message2print = "{returning" + "; set-af-pipe4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
  
#</function4xi> 

              
# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-default-family4xi" usage = "
# sets family constant default_family4xi
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_default_family4xi(param_default_family):          
    '''
    set_default_family4xi sets family constant default_family4xi
    '''
    global default_family4xi

    
           
    class2print = 'set_default_family4xi'
    method2print = 'set_default_family4xi'
    

    message2print = "{started" + "; set-default-family4xi-started: " + str(set_default_family4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  

         
    message2print = "{passed" + "; param-default-family-passed-to-set-default-family4xi: " + str(param_default_family) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
             
    if param_default_family:
        default_family4xi = param_default_family    
    else:
        default_family4xi = 'AF_INET'
        if hasattr(socket, 'AF_UNIX'):
            default_family4xi = 'AF_UNIX'
                
     
    message2print = "{set" + "; default-family4xi-set-by-set-default-family4xi to: " + str(default_family4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)          
    
    message2print = "{returning" + "; set-default-family4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
      
#</function4xi> 

                                 
# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-families4xi" usage = "
# sets family constant families4xi
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_families4xi(param_default_family):          
    '''
    set_families4xi sets family constant families4xi
    '''
    global families4xi
  

           
    class2print = 'set_families4xi'
    method2print = 'set_families4xi'
    

    message2print = "{started" + "; set-families4xi-started: " + str(set_families4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  

         
    message2print = "{passed" + "; param-default-family-passed-to-set-families4xi: " + str(param_default_family) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
             
    if param_default_family:
        families4xi = param_default_family    
    else:
        families4xi = ['AF_INET']
    
    if hasattr(socket, 'AF_UNIX'):
            families4xi += ['AF_UNIX']   
                
     
    message2print = "{set" + "; families4xi-set-by-set-families4xi to: " + str(families4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)          
    
    message2print = "{returning" + "; set-families4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
      
#</function4xi> 

                         
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-af-inet4xi" usage = "
# sets family constant AF_INET4XI
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_af_inet4xi():          
    '''
    get_af_inet4xi sets family constant AF_INET4XI
    '''
    global AF_INET4XI
    
           
    class2print = 'get_af_inet4xi'
    method2print = 'get_af_inet4xi'
    

    message2print = "{started" + "; get-af-inet4xi-started: " + str(get_af_inet4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
    
    message2print = "{returning" + "; af-inet4xi-returning-by-get-af-inet4xi: " + str(AF_INET4XI) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)                          
    
    return AF_INET4XI
#</function4xi> 

     
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-af-unix4xi" usage = "
# sets family constant AF_UNIX4XI
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_af_unix4xi():          
    '''
    get_af_unix4xi sets family constant AF_UNIX4XI
    '''
    global AF_UNIX4XI
    class2print = 'get_af_unix4xi'
    method2print = 'get_af_unix4xi'
    

    message2print = "{started" + "; get-af-unix4xi-started: " + str(get_af_unix4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
    
    message2print = "{returning" + "; af-unix4xi-returning-by-get-af-unix4xi: " + str(AF_UNIX4XI) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)                          
           
    return AF_UNIX4XI
#</function4xi> 

     
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-af-pipe4xi" usage = "
# gets family constant AF_PIPE4XI
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_af_pipe4xi():          
    '''
    get_af_pipe4xi gets family constant AF_PIPE4XI
    '''
    global AF_PIPE4XI
    class2print = 'get_af_pipe4xi'
    method2print = 'get_af_pipe4xi'
    

    message2print = "{started" + "; get-af-pipe4xi-started: " + str(get_af_pipe4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
    
    message2print = "{returning" + "; af-pipe4xi-returning-by-get-af-pipe4xi: " + str(AF_PIPE4XI) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)                          
           
    return AF_PIPE4XI   
#</function4xi> 

 
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-default-family4xi" usage = "
# gets family constant default_family4xi
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_default_family4xi():          
    '''
    get_default_family4xi gets family constant default_family4xi
    '''
    global default_family4xi
    
    class2print = 'get_default_family4xi'
    method2print = 'get_default_family4xi'
    
    message2print = "{started" + "; get-default-family4xi-started: " + str(get_default_family4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
           
    message2print = "{returning" + "; default-family4xi-returning-by-get-default-family4xi: " + str(default_family4xi) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)                          
         
           
    return default_family4xi
    
#</function4xi> 

             
                           
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-families4xi" usage = "
# gets family constant families4xi
#"> 
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_families4xi():          
    '''
    get_families4xi gets family constant families4xi
    '''
    global families4xi
    

    class2print = 'get_families4xi'
    method2print = 'get_families4xi'
    

    message2print = "{started" + "; get-families4xi-started: " + str(get_families4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  

    init_families4xi()
                   
    message2print = "{returning" + "; families4xi-returning-by-get-families4xi: " + str(families4xi) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)                          
      

    return families4xi
#</function4xi> 

     
            
# =================================================================================================
#<class4xi class = "ConstantFamily4Xi" base = "object" child = "None" synopsis = "offers services for family constants" usage = "Setting system family constants"
#>
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
# =================================================================================================
class ConstantFamily4Xi(object): #<-- inherits from object class
    '''
    ConstantLogger4xi offers services for family constants
    ''' 
    # ---------------------------------------------------------------------------------------------
    # Public API of this class
    # ---------------------------------------------------------------------------------------------    
    #<expose4xi expose = "
    _exposed_ = ('init_af_inet', 'init_af_unix', 'init_af_pipe',
                 'set_af_inet', 'set_af_unix', 'set_af_pipe',
                 'get_af_inet', 'get_af_unix', 'get_af_pipe',
                 'init_default_family', 'init_families', 'set_default_family',
                 'set_families', 'get_default_family', 'get_families',
                 'sense', 'reason', 'ace')          
    #"
    #/>
                                                
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init" usage = "initializes family constants">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------   
    def __init__(self, inet_param='AF_INET', unix_param='AF_UNIX', pipe_param='AF_PIPE', family_param=None,families_param=None):
        '''
        ConstantFamily4Xi __init__: initializes family constants
        '''

        class2print = 'ConstantFamily4Xi'
        method2print = '__init__'

        message2print = "{started" + "; init-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
                        
        message2print = "{passed" + "; inet-param-passed-to-init-of-ConstantFamily4Xi: " + str(inet_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
                        
        message2print = "{passed" + "; unix-param-passed-to-init-of-ConstantFamily4Xi: " + str(unix_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
                        
        message2print = "{passed" + "; pipe-param-passed-to-init-of-ConstantFamily4Xi: " + str(pipe_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
                        
        message2print = "{passed" + "; family-param-passed-to-init-of-ConstantFamily4Xi: " + str(family_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
                      
        message2print = "{passed" + "; families-param-passed-to-init-of-ConstantFamily4Xi: " + str(families_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
           
        message2print = "{borning" + "; constantfamily2xi-of-ConstantFamily4Xi-borning: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)       

                      
        message2print = "{inheriting" + "; object-inheriting-by-constantfamily2xi-of-ConstantFamily4Xi: " + str(object)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
        
                   
        init_af_inet4xi(inet_param)
        init_af_unix4xi(unix_param)
        init_af_pipe4xi(pipe_param)
        init_default_family4xi()
        init_families4xi()


        message2print = "{activated" + "; constantfamily2xi-of-ConstantFamily4Xi-activated: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
        
        message2print = "{inherited" + "; object-inherited-by-constantfamily2xi-of-ConstantFamily4Xi: " + str(object)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                        
        message2print = "{returning" + "; constantfamily2xi-of-ConstantFamily4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
             
    #</methodize4xi>
            
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-af-inet-of-ConstantFamily4Xi" usage = "sets family constant AF_INET4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_af_inet(self,inet_param):          
        '''
        ConstantFamily4Xi method init_af_inet sets family constant AF_INET4XI
        '''


        class2print = 'ConstantFamily4Xi'
        method2print = 'init_af_inet'
        

        message2print = "{started" + "; init-af-inet-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 

                        
        message2print = "{passed" + "; inet_param-passed-to-init-af-inet-of-ConstantFamily4Xi: " + str(inet_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
           
        init_af_inet4xi(inet_param)

                   
                        
        message2print = "{returning" + "; init-af-inet-of-ConstantFamily4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
  
                        
    #</methodize4xi>
         
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-af-unix-of-ConstantFamily4Xi" usage = "sets family constant AF_UNIX4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_af_unix(self,unix_param):          
        '''
        ConstantFamily4Xi method init_af_unix sets family constant AF_UNIX4XI
        '''

        class2print = 'ConstantFamily4Xi'
        method2print = 'init_af_unix'
        

        message2print = "{started" + "; init-af-unix-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
         
                        
        message2print = "{passed" + "; unix_param-passed-to-init-af-unix-of-ConstantFamily4Xi: " + str(unix_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
    
                
        init_af_unix4xi(unix_param)
                   
                        
        message2print = "{returning" + "; init-af-unix-of-ConstantFamily4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
  
    #</methodize4xi>
                        
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-af-pipe-of-ConstantFamily4Xi" usage = "initializes family constant AF_PIPE4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_af_pipe(self,pipe_param):          
        '''
        ConstantFamily4Xi method init_af_pipe initializes family constant AF_PIPE4XI
        '''

        class2print = 'ConstantFamily4Xi'
        method2print = 'init_af_pipe'

        message2print = "{started" + "; init-af-pipe-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                
 
                        
        message2print = "{passed" + "; pipe_param-passed-to-init-af-pipe-of-ConstantFamily4Xi: " + str(pipe_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
    
                
        init_af_pipe4xi(pipe_param)   
                   
                        
        message2print = "{returning" + "; init-af-pipe-of-ConstantFamily4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
  
    #</methodize4xi>
                            
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-default-family-of-ConstantFamily4Xi" usage = "initializes family constant default_family4xi">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_default_family(self, param_default_family=None):          
        '''
        init_default_family initializes family constant default_family4xi
        '''

        class2print = 'ConstantFamily4Xi'
        method2print = 'init_default_family'
        

        message2print = "{started" + "; init-default-family-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
 
                        
        message2print = "{passed" + "; param-default-family-passed-to-init-default-family-of-ConstantFamily4Xi: " + str(param_default_family) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
     
                
        init_default_family4xi()
        
                    
                        
        message2print = "{returning" + "; init-default-family-of-ConstantFamily4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
  
    #</methodize4xi>
                    
                               
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-families-of-ConstantFamily4Xi" usage = "initializes family constant families4xi">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_families(self,param_default_family):          
        '''
        init_families initializes family constant families4xi
        '''

        class2print = 'ConstantFamily4Xi'
        method2print = 'init_families'

        message2print = "{started" + "; init-families-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
 
                        
        message2print = "{passed" + "; param-default-family-passed-to-init-families-of-ConstantFamily4Xi: " + str(param_default_family) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
    
                
        init_families4xi(param_default_family)
        
                   
                        
        message2print = "{returning" + "; init-families-of-ConstantFamily4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
  
    #</methodize4xi>
                                    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-af-inet-of-ConstantFamily4Xi" usage = "sets family constant AF_INET4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_af_inet(self,inet_param):          
        '''
        ConstantFamily4Xi method set_af_inet sets family constant AF_INET4XI
        '''

        class2print = 'ConstantFamily4Xi'
        method2print = 'set_af_inet'
        

        message2print = "{started" + "; set-af-inet-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
 
                        
        message2print = "{passed" + "; inet-param-passed-to-set-af-inet-of-ConstantFamily4Xi: " + str(inet_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
    
                
        set_af_inet4xi(inet_param)
                   
                        
        message2print = "{returning" + "; set-af-inet-of-ConstantFamily4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
  
    #</methodize4xi>
                            
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-af-unix-of-ConstantFamily4Xi" usage = "sets family constant AF_UNIX4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_af_unix(self,unix_param):          
        '''
        ConstantFamily4Xi method set_af_unix sets family constant AF_UNIX4XI
        '''

        class2print = 'ConstantFamily4Xi'
        method2print = 'set_af_unix'
        

        message2print = "{started" + "; set-af-unix-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
 
                        
        message2print = "{passed" + "; unix-param-passed-to-set-af-unix-of-ConstantFamily4Xi: " + str(unix_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
    
                
        set_af_unix4xi(unix_param)
                   
                        
        message2print = "{returning" + "; set-af-unix-of-ConstantFamily4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
  
    #</methodize4xi>
                        
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-af-pipe-of-ConstantFamily4Xi" usage = "sets family constant AF_PIPE4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_af_pipe(self,pipe_param):          
        '''
        ConstantFamily4Xi method set_af_pipe sets family constant AF_PIPE4XI
        '''

        class2print = 'ConstantFamily4Xi'
        method2print = 'set_af_pipe'
        

        message2print = "{started" + "; set-af-pipe-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)           
 
                        
        message2print = "{passed" + "; pipe-param-passed-to-set-af-pipe-of-ConstantFamily4Xi: " + str(pipe_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
    
                
        set_af_pipe4xi(pipe_param)
                   
                        
        message2print = "{returning" + "; set-af-pipe-of-ConstantFamily4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
  
    #</methodize4xi>
                            
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-default-family-of-ConstantFamily4Xi" usage = "sets family constant default_family4xi">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_default_family(self,param_default_family):          
        '''
        set_default_family sets family constant default_family4xi
        '''

        class2print = 'ConstantFamily4Xi'
        method2print = 'set_default_family'

        message2print = "{started" + "; set-default-family-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
 
                        
        message2print = "{passed" + "; param-default-family-passed-to-set-default-family-of-ConstantFamily4Xi: " + str(param_default_family) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
    
                
        set_default_family4xi(param_default_family)
                   
                        
        message2print = "{returning" + "; set-default-family-of-ConstantFamily4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
  
    #</methodize4xi>
                    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-default-family-of-ConstantFamily4Xi" usage = "returns default_family4xi">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_default_family(self):          
        '''
        get_default_family returns default_family4xi
        '''

        class2print = 'ConstantFamily4Xi'
        method2print = 'get_default_family'

        message2print = "{started" + "; get-default-family-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)           
         
        message2print = "{returning" + "; get-default-family4xi-function-returning-by-get-default-family-of-ConstantFamily4Xi: " + str(get_default_family4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
                
                
        return get_default_family4xi()        
                
 
    #</methodize4xi>
                                   
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-families-of-ConstantFamily4Xi" usage = "sets family constant families4xi">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_families(self,param_default_family):          
        '''
        set_families sets family constant families4xi
        '''

        class2print = 'ConstantFamily4Xi'
        method2print = 'set_families'
        

        message2print = "{started" + "; set-families-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)             
 
                        
        message2print = "{passed" + "; param-default-family-passed-to-set-families-of-ConstantFamily4Xi: " + str(param_default_family) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
    
                
        set_families4xi(param_default_family)
                   
        message2print = "{returning" + "; set-families-of-ConstantFamily4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
        

        
    #</methodize4xi>
                    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-af-inet-of-ConstantFamily4Xi" usage = "gets family constant AF_INET4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_af_inet(self):          
        '''
        ConstantFamily4Xi method get_af_inet gets family constant AF_INET4XI
        '''

        class2print = 'ConstantFamily4Xi'
        method2print = 'get_af_inet'

        message2print = "{started" + "; get-af-inet-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                
        inet2xi = get_af_inet4xi()
        if inet2xi:
            
         
            message2print = "{returning" + "; inet2xi-returning-by-get-af-inet-of-ConstantFamily4Xi: " + str(inet2xi) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)  
   
        
            return inet2xi
        else:
            # -----------------------------------------------------------------------------------------
            # return meaningul information
            # -----------------------------------------------------------------------------------------
            init_af_inet4xi()

            message2print = "{returning" + "; get-af-inet4xi-function-returning-by-get-af-inet-of-ConstantFamily4Xi: " + str(get_af_inet4xi) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)  
  
            return get_af_inet4xi() 
    #</methodize4xi>
                  
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-af-unix-of-ConstantFamily4Xi" usage = "gets family constant AF_UNIX4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_af_unix(self):          
        '''
        ConstantFamily4Xi method get_af_unix gets family constant AF_UNIX4XI
        '''

        class2print = 'ConstantFamily4Xi'
        method2print = 'get_af_unix'

        message2print = "{started" + "; get-af-unix-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)           
  
                
        unix2xi = get_af_unix4xi()
        if unix2xi:
            
         
            message2print = "{returning" + "; unix2xi-returning-by-get-af-unix-of-ConstantFamily4Xi: " + str(unix2xi) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)  
              
        
            return unix2xi
        else:
            # -----------------------------------------------------------------------------------------
            # return meaningul information
            # -----------------------------------------------------------------------------------------
            init_af_unix4xi()
            
         
            message2print = "{returning" + "; get-af-unix4xi-function-returning-by-get-af-unix-of-ConstantFamily4Xi: " + str(get_af_unix4xi) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)  
   
            
            return get_af_unix4xi()             
    #</methodize4xi>
            
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-af-pipe-of-ConstantFamily4Xi" usage = "gets family constant AF_PIPE4XI">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_af_pipe(self):          
        '''
        ConstantFamily4Xi method get_af_pipe gets family constant AF_PIPE4XI
        '''

        class2print = 'ConstantFamily4Xi'
        method2print = 'get_af_pipe'

        message2print = "{started" + "; get-af-pipe-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
  
                
        pipe2xi = get_af_pipe4xi()
        if pipe2xi:
            
         
            message2print = "{returning" + "; pipe2xi-returning-by-get-af-pipe-of-ConstantFamily4Xi: " + str(pipe2xi) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)  
         
        
            return pipe2xi
        else:
            # -----------------------------------------------------------------------------------------
            # return meaningul information
            # -----------------------------------------------------------------------------------------
            init_af_pipe4xi()
            
            
         
            message2print = "{returning" + "; get-af-pipe4xi-function-returning-by-get-af-pipe-of-ConstantFamily4Xi: " + str(get_af_pipe4xi) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)  
   
            return get_af_pipe4xi()        
    #</methodize4xi>
                       
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-default-family-of-ConstantFamily4Xi" usage = "gets family constant default_family4xi">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_default_family(self):          
        '''
        get_default_family gets family constant default_family4xi
        '''

        class2print = 'ConstantFamily4Xi'
        method2print = 'get_default_family'

        message2print = "{started" + "; get-default-family-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
                
        
        f2xi = get_default_family4xi()
        if f2xi:
            
         
            message2print = "{returning" + "; default-family2xi-returning-by-get-default-family-of-ConstantFamily4Xi: " + str(f2xi) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)  

            return f2xi
        else:
            # -----------------------------------------------------------------------------------------
            # return meaningul information
            # -----------------------------------------------------------------------------------------
            init_default_family(self)
            
         
            message2print = "{returning" + "; get-default-family4xi-function-returning-by-get-default-family-of-ConstantFamily4Xi: " + str(get_default_family4xi) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)  
               
              
            return get_default_family4xi()
    #</methodize4xi>
            
 
                               
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-families-of-ConstantFamily4Xi" usage = "gets family constant families4xi">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_families(self):          
        '''
        get_families gets family constant families4xi
        '''

        class2print = 'ConstantFamily4Xi'
        method2print = 'get_families'

        message2print = "{started" + "; get-families-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
  
                
        f2xi = get_families4xi()
        if f2xi:
            
         
            message2print = "{returning" + "; f2xi-returning-by-get-families-of-ConstantFamily4Xi: " + str(f2xi) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)    
                        
        
            return f2xi
        else:
            # -----------------------------------------------------------------------------------------
            # return meaningul information
            # -----------------------------------------------------------------------------------------
            init_families4xi()
            
         
            message2print = "{returning" + "; get-families4xi-function-returning-by-get-families-of-ConstantFamily4Xi: " + str(get_families4xi) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)  
             
            return get_families4xi()
    #</methodize4xi>
                                           
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "sense-of-ConstantFamily4Xi" usage = "senses class objects">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def sense(self):
        '''
        senses ConstantFamily4Xi class objects
        '''
          
        
        class2print = 'ConstantFamily4Xi'
        method2print = 'sense'
        
        message2print = "{started" + "; sense-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------  
        message2print = "{sensing" + "; constantfamily4xi-sensing-by-sense-of-ConstantFamily4Xi: " + str(ConstantFamily4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                    
        
        # -----------------------------------------------------------------------------------------
        # get sensed knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb2xi = sense_object4xi(self)
        
        message2print = "{got" + "; kb2xi-got-by-sense-of-ConstantFamily4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # -----------------------------------------------------------------------------------------         
        try:
            kb2xi['inheritance-of-constantfamily2xi'] = object
        except:
            message2print = "{yielded" + "; kb2xi-yielded-by-sense-of-ConstantFamily4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
    
 
        message2print = "{sensed" + "; constantfamily4xi-sensed-by-sense-of-ConstantFamily4Xi: " + str(ConstantFamily4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)           
        # -----------------------------------------------------------------------------------------
        # 
        # -----------------------------------------------------------------------------------------         
         
        message2print = "{returning" + "; kb2xi-returning-by-sense-of-ConstantFamily4Xi: " + str(kb2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
         
        return kb2xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
    #</methodize4xi>
    
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "reason-of-ConstantFamily4Xi" usage = "reasons class objects">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def reason(self):
        '''
        reasons ConstantFamily4Xi class objects
        '''
                 
        
        class2print = 'ConstantFamily4Xi'
        method2print = 'reason'

        message2print = "{started" + "; reason-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{reasoning" + "; constantfamily4xi-reasoning-by-reason-of-ConstantFamily4Xi: " + str(ConstantFamily4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
                
        
        # -----------------------------------------------------------------------------------------
        # get reasoned knowledge for this object
        # -----------------------------------------------------------------------------------------         
        kb4xi = reason_object4xi(self)
        
        message2print = "{got" + "; kb4xi-got-by-reason-of-ConstantFamily4Xi: " + str(kb4xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb4xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------          
        
        message2print = "{reasoned" + "; constantfamily4xi-reasoned-by-reason-of-ConstantFamily4Xi: " + str(ConstantFamily4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
   
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
  
          
        message2print = "{returning" + "; kb4xi-returning-by-reason-of-ConstantFamily4Xi: " + str(kb4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
  
        return kb4xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi>
    

 
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "ace-of-ConstantFamily4Xi" usage = "aces class objects ">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def ace(self):
        '''
        aces ConstantFamily4Xi class objects 
        '''
               
        
        
        class2print = 'ConstantFamily4Xi'
        method2print = 'ace'
        
        message2print = "{started" + "; ace-of-ConstantFamily4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)      
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{acing" + "; constantfamily4xi-acing-by-ace-of-ConstantFamily4Xi: " + str(ConstantFamily4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                  
        
        # -----------------------------------------------------------------------------------------
        # get aced knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb8xi = ace_object4xi(self)  
        
        message2print = "{got" + "; kb8xi-got-by-ace-of-ConstantFamily4Xi: " + str(kb8xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                

        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb8xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------              
        
        message2print = "{aced" + "; constantfamily4xi-aced-by-ace-of-ConstantFamily4Xi: " + str(ConstantFamily4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
   
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb8xi-returning-by-ace-of-ConstantFamily4Xi: " + str(kb8xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                            
        return kb8xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi>
#</class4xi>
#</program4xi>

# -------------------------------------------------------------------------------------------------
# Recorded History                             
# ------------------------------------------------------------------------------------------------- 
#<record4xi record = "
#   test_constant_family4xi.txt
#   sense-test-constant-family4xi.xml
#   reason-test-constant-family4xi.xml
#   ace-test-constant-family4xi.xml
#"
#>


# -------------------------------------------------------------------------------------------------
# Legal Notice                             
# ------------------------------------------------------------------------------------------------- 
#<protect4xi protection = "copyright"
#   owner = "Small & Smart"
#   rights = "All rights reserved"
#   state = "California"
#   country = "United States of America"
#   references = "Legal notice at www.dragonxi.com; www.yourdragonxi.com; www.yourdragonxi.org; www.dragon2xi.com/; www.dragon4xi.com/; www.dragon8xi.com/ " 
#   codes = "Codes established in California and applicable to corporations in California"
#   compliance = "The California Law"
#   court = "Supreme Court of California, 350 McAllister Street, San Francisco, CA 94102-4783"
#/>

    
    

#<end4xi end = "
# -------------------------------------------------------------------------------------------------
# end of constant_family4xi.py                             
# ------------------------------------------------------------------------------------------------- 
#"
#/>

